/* IBM Confidential
* OCO Source Materials
* 5724-U98, 5655-V48, 5724-U50, 5655-V46
* © Copyright IBM Corp. 2013
* The source code for this program is not published or other -
* wise divested of its trade secrets, irrespective of what has
* been deposited with the U.S. Copyright Office.
*/
define(["dojo/_base/declare",
        "dojo/_base/lang",
        "dijit/_Widget",        
        "dijit/_TemplatedMixin",
        "dijit/_WidgetsInTemplateMixin",
        "dojo/text!./templates/DsiWizard.html",
        "dojo/i18n!./nls/widget_resources",
        "dijit/form/Button",
        "dijit/form/TextBox",
        "dijit/layout/StackContainer",
        "dijit/layout/BorderContainer",
        "dijit/layout/TabContainer",
        "dijit/layout/ContentPane",
        "idx/form/RadioButtonSet",
        "dijit/form/HorizontalSlider",
        "dijit/form/HorizontalRuleLabels",
        "dijit/form/HorizontalRule"],
		function(dDeclare,
				dLang,
				dWidget,
				dTemplatedMixin,
				dWidgetsInTemplateMixin,
				templateText,
				resources) {
return dDeclare("wizard.DsiWizard", [dWidget,dTemplatedMixin,dWidgetsInTemplateMixin], 
{
	 /**
	   * @private
	   */
	  baseClass: "dsiWizard",
	  
	  /**
	   * The path to the widget template for the dijit._TemplatedMixin base class.
	   * 
	   * @private
	   * @constant
	   * @type String
	   */
	  templateString: templateText,
	  
	  /** 
	   * Allow users to add other components (e.g. hidden fields) under password field
	   * 
	   * @private
	   */
	  isContainer: true,

	  pageTitle: resources['unknownPageTitle'],

	  pageDescription: resources['unknownPageDescription'],
	  
	  attributeMap: dLang.delegate(dWidget.prototype.attributeMap, {
			pageDescription: {node: "pageDescriptionNode", type: "innerHTML"}
	  }),

	  startup: function(){
//			if(this._started){
//				//console.log('started');
//				return;
//			}
			this.inherited(arguments);
			this.connect(this.nextButton, "onClick", "_forward");
			this.connect(this.previousButton, "onClick", "_back");
			this.connect(this.cancelButton, "onClick", "_cancel");
			this.connect(this.finishButton, "onClick", "_finish");
			
			this.nextButton.set("label", resources['nextButtonLabel']);
			this.previousButton.set("label", resources['previousButtonLabel']);
			this.cancelButton.set("label", resources['cancelButtonLabel']);
			this.finishButton.set("label", resources['finishButtonLabel']);
	  },

	  /**
	   * Reset the content of this wizard - for reusable dialog
	   */
	  initWizard:function() {
		  //this.pageContainerNode.selectChild()
		  var pages = this.pageContainerNode.getChildren();
		  for (var i in pages) {
			  pages[i].pageInit();
		  }
	  },

	  selectPage:function(page) {
		  this.pageContainerNode.selectChild(page);
		  page.pageLoad();
		  this._checkButtons();
		  this._setPageTitleAndDescription();
	  },

	  _setPageTitleAndDescription:function() {
		  /*
		  	this.pageTitle = this.pageContainerNode.selectedChildWidget.getTitle();
			this.pageDescription = this.pageContainerNode.selectedChildWidget.getDescription();
			this.pageTitleNode.innerHTML = this.pageTitle;
			*/
			this.set('pageDescription', this.pageContainerNode.selectedChildWidget.getDescription());
	  },

	  _checkButtons: function() {
		  var selectedPage = this.pageContainerNode.selectedChildWidget;		  
		  var enableNext = true;
		  var enablePrevious = true;
		  var enableFinish = true;
		  if (!selectedPage.isReady() || selectedPage.cannotGoNext) {
			  enableNext = false;
		  }
		  if (selectedPage.cannotGoBack) {
			  enablePrevious = false;
		  }
		  
		  if (!selectedPage.cannotGoNext || pageWizardMode == "new"){
			  enableFinish = false;
		  }
		  /*
		  if (dsiWizardObject.wizardMode == "edit"){
			  enableFinish = true;
		  }*/
		  this.nextButton.set("disabled", !enableNext);
		  this.previousButton.set("disabled", !enablePrevious);
		  this.cancelButton.set("disabled",false);		  
		 
		  this.finishButton.set("disabled", !enableFinish);
	  },
	  
	  _setButtonStates: function(state){
		  	this.nextButton.set("disabled",state);
			this.previousButton.set("disabled",state);
			this.cancelButton.set("disabled",state);
			this.finishButton.set("disabled",state);
	  },

	  _cancel: function() {
		  //assumes parent is a dialog
		  dsiWizardSecondPage.clearJarGrid();
		  this.getParent().onCancel();
	  },

	  _finish: function() {
		  console.log("finished pressed");
		  //Set the Description,Optim Directory and the default schema
		  var selected = dsiWizardThirdPage.grid.selection.getSelected();
		  var rowData = selected[0];
		  pagePayload.jdbcConnectionInformation.additionalProperties['org.eclipse.datatools.connectivity.db.defaultSchema']= rowData.schema;
		  if (inBootStrapMode){
			  pagePayload.datastoreName = "OCMCONN";
			  pagePayload.datastoreType = "STARTUP";
			  pagePayload.version = dsiWizardFirstPage.versionComboBox.get("value");
			  pagePayload.vendor = dsiWizardFirstPage.vendorComboBox.get("value");
		  }else{
			  pagePayload.datastoreName = rowData.name;
			  pagePayload.description = rowData.description;
			  pagePayload.version = dsiWizardFirstPage.versionComboBox.get("value");
			  pagePayload.vendor = dsiWizardFirstPage.vendorComboBox.get("value");			  
		  }
		  this.getParent().onExecute();
		  this.onFinish();
	  },

	  _forward: function(){
			// summary:
			//		callback when next button is clicked			
			this.pageContainerNode.forward();
			this._setPageTitleAndDescription();
			this._checkButtons();
			var selectedPage = this.pageContainerNode.selectedChildWidget;
			selectedPage.pageLoad();
	  },

	  _back: function() {
		  this.pageContainerNode.back();
		  this._setPageTitleAndDescription();
		  this._checkButtons();
	  },

	  onFinish: function() {
		  //user of this wizard should override this function
	  }
});

});